@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10926 2018-03-26 07:30:32Z Kevin $
+# $Id: __init__.py 10940 2018-03-27 06:58:11Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-03-26 15:30:32 +0800 (週一, 26 三月 2018) $
-# $Revision: 10926 $
+# $Date: 2018-03-27 14:58:11 +0800 (週二, 27 三月 2018) $
+# $Revision: 10940 $
 """
 Celery tasks which should be run at cloud worker.
 """
@@ -56,7 +56,11 @@ def send(email_messages, fail_silently=False, *args, **kws):
     folderName = finishDateTime.strftime('%Y-%m-%d')
     folderPath = os.path.join('sent', folderName)
     if not os.path.exists(folderPath):
-        os.makedirs(folderPath)
+        try:
+            os.makedirs(folderPath)
+        except Exception as e:
+            logger.error("os.makedirs(folderPath):" + str(e))
+            pass
 
     sesExtra = []
 
