@@ -33,8 +33,12 @@ if not STATIC_DIR:
 
 TEMPLATE_DIR = None
 if hasattr(settings, "TEMPLATES"):
-    TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
-else:
+    try:
+        TEMPLATE_DIR = settings.TEMPLATES[0]['DIRS'][0]
+    except Exception as e:
+        pass
+
+if not STATIC_DIR:
     TEMPLATE_DIR = os.path.join(settings.BASE_DIR, "templates")
 
 BACKUP_DIR_NAME = "_Iuno.template_editor_backup" 
