@@ -15,6 +15,7 @@
 # $Date: 2017-12-10 21:03:41 +0800 (週日, 10 十二月 2017) $
 # $Revision: 10628 $
 
+import os
 import shutil
 
 from django.core.management.base import BaseCommand
@@ -30,4 +31,7 @@ class Command(BaseCommand):
 
         # delete backup file
         shutil.rmtree(BACKUP_FILE_DIR)
+
+        if not os.path.isdir(BACKUP_FILE_DIR):
+            os.mkdir(BACKUP_FILE_DIR)
         print "Successfully."
\ No newline at end of file
